@@ -27,6 +27,10 @@ impl ColorCommand for FormatCommand {
             "hsl-hue" => format!("{:.0}", color.to_hsla().h),
             "hsl-saturation" => format!("{:.4}", color.to_hsla().s),
             "hsl-lightness" => format!("{:.4}", color.to_hsla().l),
+            "hsv" => color.to_hsv_string(Format::Spaces),
+            "hsv-hue" => format!("{:.0}", color.to_hsva().h),
+            "hsv-saturation" => format!("{:.4}", color.to_hsva().s),
+            "hsv-value" => format!("{:.4}", color.to_hsva().v),
             "lch" => color.to_lch_string(Format::Spaces),
             "lch-lightness" => format!("{:.2}", color.to_lch().l),
             "lch-chroma" => format!("{:.2}", color.to_lch().c),
@@ -34,6 +38,10 @@ impl ColorCommand for FormatCommand {
             "lab" => color.to_lab_string(Format::Spaces),
             "lab-a" => format!("{:.2}", color.to_lab().a),
             "lab-b" => format!("{:.2}", color.to_lab().b),
+            "oklab" => color.to_oklab_string(Format::Spaces),
+            "oklab-l" => format!("{:.4}", color.to_oklab().l),
+            "oklab-a" => format!("{:.4}", color.to_oklab().a),
+            "oklab-b" => format!("{:.4}", color.to_oklab().b),
             "luminance" => format!("{:.3}", color.luminance()),
             "brightness" => format!("{:.3}", color.brightness()),
             "ansi-8bit" => replace_escape(&color.to_ansi_sequence(Mode::Ansi8Bit)),
